package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: May 17, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Cluster struct {
RepresentativeThreadID int64 `json:"representative_thread_id"`
Members []int64 `json:"members"`
}
type Options struct {
MaxSize int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.